package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbMemberSubjectWrong;

import java.util.List;
import java.util.Map;

/**
 * 我的错题Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-07
 */
public interface TbMemberSubjectWrongMapper
{
    /**
     * 查询我的错题
     *
     * @param memberSubjectWrongId 我的错题主键
     * @return 我的错题
     */
    public TbMemberSubjectWrong selectTbMemberSubjectWrongByMemberSubjectWrongId(Long memberSubjectWrongId);

    /**
     * 查询我的错题列表
     *
     * @param tbMemberSubjectWrong 我的错题
     * @return 我的错题集合
     */
    public List<TbMemberSubjectWrong> selectTbMemberSubjectWrongList(TbMemberSubjectWrong tbMemberSubjectWrong);

    /**
     * 新增我的错题
     *
     * @param tbMemberSubjectWrong 我的错题
     * @return 结果
     */
    public int insertTbMemberSubjectWrong(TbMemberSubjectWrong tbMemberSubjectWrong);

    /**
     * 修改我的错题
     *
     * @param tbMemberSubjectWrong 我的错题
     * @return 结果
     */
    public int updateTbMemberSubjectWrong(TbMemberSubjectWrong tbMemberSubjectWrong);

    /**
     * 删除我的错题
     *
     * @param memberSubjectWrongId 我的错题主键
     * @return 结果
     */
    public int deleteTbMemberSubjectWrongByMemberSubjectWrongId(Long memberSubjectWrongId);

    /**
     * 批量删除我的错题
     *
     * @param memberSubjectWrongIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbMemberSubjectWrongByMemberSubjectWrongIds(Long[] memberSubjectWrongIds);

    /**
     * 错题数量
     *
     * @param params 参数
     * @return 结果
     */
    public int countByParams(Map<String, Object> params);
}
